#ifndef NT2_INCLUDE_FUNCTIONS_CAST_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CAST_HPP_INCLUDED

#include <nt2/operator/include/functions/cast.hpp>

#endif
